@@ -67,7 +67,7 @@ DownloadManager::DownloadManager(QWidget* parent)
 
     connect(ui->clearButton, &QAbstractButton::clicked, this, &DownloadManager::clearList);
 
-    QShortcut* clearShortcut = new QShortcut(QKeySequence("CTRL+L"), this);
+    auto* clearShortcut = new QShortcut(QKeySequence("CTRL+L"), this);
     connect(clearShortcut, &QShortcut::activated, this, &DownloadManager::clearList);
 
     loadSettings();
@@ -106,7 +106,7 @@ void DownloadManager::show()
 void DownloadManager::resizeEvent(QResizeEvent* e)
 {
     QWidget::resizeEvent(e);
-    emit resized(size());
+    Q_EMIT resized(size());
 }
 
 void DownloadManager::keyPressEvent(QKeyEvent* e)
@@ -133,60 +133,24 @@ void DownloadManager::closeDownloadTab(QWebEngineDownloadItem *item) const
         if (page->history()->count() != 0) {
             return false;
         }
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 12, 0)
         Q_UNUSED(url)
         return true;
-#else
-        if (page->url() != QUrl()) {
-            return false;
-        }
-        QUrl tabUrl = page->requestedUrl();
-        if (tabUrl.isEmpty()) {
-            tabUrl = QUrl(view->webTab()->locationBar()->text());
-        }
-        return tabUrl.host() == url.host();
-#endif
     };
 
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 12, 0)
     if (!item->page()) {
         return;
     }
-    WebPage *page = qobject_cast<WebPage*>(item->page());
+    auto *page = qobject_cast<WebPage*>(item->page());
     if (!page) {
         return;
     }
-    TabbedWebView *view = qobject_cast<TabbedWebView*>(page->view());
+    auto *view = qobject_cast<TabbedWebView*>(page->view());
     if (!view) {
         return;
     }
     if (testWebView(view, QUrl())) {
         view->closeView();
     }
-#else
-    BrowserWindow* mainWindow = mApp->getWindow();
-    // If the main window was closed, there is no need to go further
-    if (mainWindow == nullptr) {
-        return;
-    }
-
-    if (testWebView(mainWindow->weView(), item->url())) {
-        mainWindow->weView()->closeView();
-        return;
-    }
-
-    const auto windows = mApp->windows();
-    for (auto *window : windows) {
-        const auto tabs = window->tabWidget()->allTabs();
-        for (auto *tab : tabs) {
-            auto *view = tab->webView();
-            if (testWebView(view, item->url())) {
-                view->closeView();
-                return;
-            }
-        }
-    }
-#endif
 }
 
 QWinTaskbarButton *DownloadManager::taskbarButton()
@@ -228,7 +192,7 @@ void DownloadManager::timerEvent(QTimerEvent* e)
             return;
         }
         for (int i = 0; i < ui->list->count(); i++) {
-            DownloadItem* downItem = qobject_cast<DownloadItem*>(ui->list->itemWidget(ui->list->item(i)));
+            auto* downItem = qobject_cast<DownloadItem*>(ui->list->itemWidget(ui->list->item(i)));
             if (!downItem || downItem->isCancelled() || !downItem->isDownloading()) {
                 continue;
             }
@@ -277,7 +241,7 @@ void DownloadManager::clearList()
 {
     QList<DownloadItem*> items;
     for (int i = 0; i < ui->list->count(); i++) {
-        DownloadItem* downItem = qobject_cast<DownloadItem*>(ui->list->itemWidget(ui->list->item(i)));
+        auto* downItem = qobject_cast<DownloadItem*>(ui->list->itemWidget(ui->list->item(i)));
         if (!downItem) {
             continue;
         }
@@ -287,7 +251,7 @@ void DownloadManager::clearList()
         items.append(downItem);
     }
     qDeleteAll(items);
-    emit downloadsCountChanged();
+    Q_EMIT downloadsCountChanged();
 }
 
 void DownloadManager::download(QWebEngineDownloadItem *downloadItem)
@@ -397,8 +361,8 @@ void DownloadManager::download(QWebEngineDownloadItem *downloadItem)
     downloadItem->accept();
 
     // Create download item
-    QListWidgetItem* listItem = new QListWidgetItem(ui->list);
-    DownloadItem* downItem = new DownloadItem(listItem, downloadItem, QFileInfo(downloadPath).absolutePath(), QFileInfo(downloadPath).fileName(), openFile, this);
+    auto* listItem = new QListWidgetItem(ui->list);
+    auto* downItem = new DownloadItem(listItem, downloadItem, QFileInfo(downloadPath).absolutePath(), QFileInfo(downloadPath).fileName(), openFile, this);
     downItem->setDownTimer(downloadTimer);
     downItem->startDownloading();
     connect(downItem, &DownloadItem::deleteItem, this, &DownloadManager::deleteItem);
@@ -408,7 +372,7 @@ void DownloadManager::download(QWebEngineDownloadItem *downloadItem)
     downItem->show();
 
     m_activeDownloadsCount++;
-    emit downloadsCountChanged();
+    Q_EMIT downloadsCountChanged();
 }
 
 int DownloadManager::downloadsCount() const
@@ -426,7 +390,7 @@ void DownloadManager::downloadFinished(bool success)
     m_activeDownloadsCount = 0;
     bool downloadingAllFilesFinished = true;
     for (int i = 0; i < ui->list->count(); i++) {
-        DownloadItem* downItem = qobject_cast<DownloadItem*>(ui->list->itemWidget(ui->list->item(i)));
+        auto* downItem = qobject_cast<DownloadItem*>(ui->list->itemWidget(ui->list->item(i)));
         if (!downItem) {
             continue;
         }
@@ -439,7 +403,7 @@ void DownloadManager::downloadFinished(bool success)
         downloadingAllFilesFinished = false;
     }
 
-    emit downloadsCountChanged();
+    Q_EMIT downloadsCountChanged();
 
     if (downloadingAllFilesFinished) {
         if (success && qApp->activeWindow() != this) {
@@ -475,7 +439,7 @@ bool DownloadManager::canClose()
 
     bool isDownloading = false;
     for (int i = 0; i < ui->list->count(); i++) {
-        DownloadItem* downItem = qobject_cast<DownloadItem*>(ui->list->itemWidget(ui->list->item(i)));
+        auto* downItem = qobject_cast<DownloadItem*>(ui->list->itemWidget(ui->list->item(i)));
         if (!downItem) {
             continue;
         }
