@@ -28,13 +28,13 @@ class FALKON_EXPORT ProgressBar : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ProgressBar(QWidget* parent = 0);
+    explicit ProgressBar(QWidget* parent = nullptr);
 
 public Q_SLOTS:
     void setValue(int value);
 
 protected:
-    void paintEvent(QPaintEvent* e);
+    void paintEvent(QPaintEvent* e) override;
     void initStyleOption(QStyleOptionProgressBar* option);
 
 private:
