@@ -65,11 +65,11 @@ void TreeWidget::insertTopLevelItems(int index, const QList<QTreeWidgetItem*> &i
 void TreeWidget::mousePressEvent(QMouseEvent* event)
 {
     if (event->modifiers() == Qt::ControlModifier) {
-        emit itemControlClicked(itemAt(event->pos()));
+        Q_EMIT itemControlClicked(itemAt(event->pos()));
     }
 
     if (event->buttons() == Qt::MiddleButton) {
-        emit itemMiddleButtonClicked(itemAt(event->pos()));
+        Q_EMIT itemMiddleButtonClicked(itemAt(event->pos()));
     }
 
     QTreeWidget::mousePressEvent(event);
@@ -103,10 +103,10 @@ QList<QTreeWidgetItem*> TreeWidget::allItems()
 
 void TreeWidget::filterString(const QString &string)
 {
-    QList<QTreeWidgetItem*> _allItems = allItems();
+    const QList<QTreeWidgetItem*> _allItems = allItems();
     QList<QTreeWidgetItem*> parents;
     bool stringIsEmpty = string.isEmpty();
-    foreach (QTreeWidgetItem* item, _allItems) {
+    for (QTreeWidgetItem* item : _allItems) {
         bool containsString = stringIsEmpty || item->text(0).contains(string, Qt::CaseInsensitive);
         if (containsString) {
             item->setHidden(false);
@@ -143,7 +143,7 @@ void TreeWidget::filterString(const QString &string)
 bool TreeWidget::appendToParentItem(const QString &parentText, QTreeWidgetItem* item)
 {
     QList<QTreeWidgetItem*> list = findItems(parentText, Qt::MatchExactly);
-    if (list.count() == 0) {
+    if (list.isEmpty()) {
         return false;
     }
     QTreeWidgetItem* parentItem = list.at(0);
@@ -170,7 +170,7 @@ bool TreeWidget::appendToParentItem(QTreeWidgetItem* parent, QTreeWidgetItem* it
 bool TreeWidget::prependToParentItem(const QString &parentText, QTreeWidgetItem* item)
 {
     QList<QTreeWidgetItem*> list = findItems(parentText, Qt::MatchExactly);
-    if (list.count() == 0) {
+    if (list.isEmpty()) {
         return false;
     }
     QTreeWidgetItem* parentItem = list.at(0);
